Keen | Wizard v3
Description: Keen custom wizard demo

# Customer Relationship Management

New Order

### Wizard v3

Reports
Create New Account
Username: Please enter your username
Email address: We'll never share your email with anyone else
Password: Enter your password. Min 6 characters long.
Setup Your Profile
Name: Please enter your full name
Contact: Enter your contact number
Mailing Address
Address Line 1:
City:
State:
Address Line 2:
Zip Code:
Country:
Setup Your Business Details
Company Name: Please enter your company name
Company Registered ID: Please enter your company registered ID
Company Email: Please enter your company email
Company Contact: Please enter your comapny contact
Communication:
Email SMS Phone
Setup Billing Account
Cardholder Name: Please enter the cardholder name
Card number: Enter the card number
Exp Month:
Exp Year:
CVV:
Billing Address
Address Line 1:
City:
State:
Address Line 2:
Zip Code:
Country:
Finalize your purchase
Membership:
Premium Partner 30 days free trial and lifetime free updates
Free Membership 24/7 support and Lifetime access
Click here to receive our latest promotions and news
Click here to indicate that you have read and agree to the terms presented in the Terms and Conditions agreement
Previous
Submit
Next Step

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!